# The FHIR Cloud Package

This package contains FHIR-related functionality for integrating with cloud services. The Azure Health Data Services (FHIR) platform stores the exported output data to blob stoarage. This module contains functionality to simplify retrieval of FHIR-exported content.
